@@ -12,11 +12,12 @@ print <<"...";
 # abstract:  Pegex Grammar for a Pegex Grammar
 # author:    Ingy döt Net <ingy\@cpan.org>
 # license:   perl
-# copyright: 2011
+# copyright: 2010, 2011
 
 package Pegex::Compiler::Grammar;
-use Mouse;
-extends 'Pegex::Grammar';
+use base 'Pegex::Grammar';
+use strict;
+use warnings;
 
 sub grammar_tree {
     return +$perl;
